@@ -173,7 +173,7 @@ plot.qv <- function(x, width=2, ylab = "estimate",
     frame <- x$qvframe
     if (is.na(frame$estimate[1]))
         stop("x has no parameter estimates to plot")
-    levels <- as.factor(row.names(frame))
+    levels <- factor(row.names(frame), levels=row.names(frame))
     xvalues <- seq(along=levels)
     est <- frame$estimate
     se <- frame$quasiSE
